DeduplicationConfig class

请求去重/防抖配置

Constructors

DeduplicationConfig({DeduplicationMode mode = DeduplicationMode.deduplication, Duration debounceDelay = const Duration(milliseconds: 300), Duration throttleInterval = const Duration(milliseconds: 300)})

Properties

debounceDelay Duration
防抖延迟时间(仅在 debounce 模式下有效)
final
hashCode int
The hash code for this object.
no setterinherited
mode DeduplicationMode
去重模式
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
throttleInterval Duration
节流间隔时间(仅在 throttle 模式下有效)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited