LogMode enum

日志打印模式

Inheritance
Available extensions

Values

complete → const LogMode

完整链路模式(推荐)- 响应时一起打印请求+响应+耗时 优点:请求-响应完美关联,并发友好,自动显示耗时

realTime → const LogMode

实时模式 - 请求和响应分别打印 优点:实时性好,立即看到请求发出

brief → const LogMode

简要模式 - 只打印关键信息 优点:日志简洁,适合生产环境

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogMode>
A constant List of the values in this enum, in order of their declaration.