QueueConfig class
请求队列配置
Constructors
- QueueConfig({int maxConcurrency = 10, bool enabled = true})
Properties
- enabled → bool
-
是否启用队列(默认 true)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrency → int
-
最大并发数(默认 10)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited