LogInterceptor class

日志拦截器 用于打印 HTTP 请求和响应的详细信息

Constructors

LogInterceptor({bool printBody = true, LogMode logMode = LogMode.complete, bool showRequestHint = true})

Properties

hashCode int
The hash code for this object.
no setterinherited
logMode LogMode
日志打印模式
final
printBody bool
是否打印请求/响应 body
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showRequestHint bool
是否在请求时显示简要提示(仅在 complete 模式下有效)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited