QueueStatus class
队列状态
Constructors
- QueueStatus({required int queueLength, required int runningCount, required bool isPaused})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPaused → bool
-
是否已暂停
final
- queueLength → int
-
队列长度
final
- runningCount → int
-
正在执行的请求数量
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited