PathBasedResponseParser class

路径匹配解析器 根据请求路径选择不同的解析器

Implemented types

Constructors

PathBasedResponseParser({required List<PathMatcher> matchers, required ResponseParser defaultParser})

Properties

defaultParser ResponseParser
final
hashCode int
The hash code for this object.
no setterinherited
matchers List<PathMatcher>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse<T>(RawHttpResponse raw) Response<T>
解析响应 raw 原始 HTTP 响应(statusCode、data、path) 返回用户定义的 Response,必须处理所有可能的响应结构
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited