PathMatcher class
路径匹配规则 用于根据请求路径选择不同的解析器
Constructors
- PathMatcher({required Pattern pattern, required ResponseParser parser})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parser → ResponseParser
-
对应的解析器
final
- pattern → Pattern
-
路径模式(支持正则表达式或字符串匹配)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
matches(
String path) → bool - 检查路径是否匹配
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited