SSEEvent class

Server-Sent Events (SSE) 事件模型

Constructors

SSEEvent({required String data, String? event, String? id, int? retry})

Properties

data String
事件数据
final
event String?
事件类型(可选)
final
hashCode int
The hash code for this object.
no setterinherited
id String?
事件 ID(可选,用于重连时指定最后接收的事件)
final
retry int?
重试间隔(毫秒,可选)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited