SSEStream class

SSE 流处理类 负责解析 SSE 数据流并转换为 SSEEvent

Constructors

SSEStream(Stream<String> _stream)

Properties

events Stream<SSEEvent>
获取事件流 注意:多次调用会返回同一个流对象,不会创建多个订阅
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
关闭流
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited