PrivacyAgreementConfig class

隐私协议弹窗配置

Constructors

PrivacyAgreementConfig({String title = '用户协议与隐私政策', String content = '欢迎使用本应用!我们非常重视您的个人信息和隐私保护。' '请您务必审慎阅读、充分理解《用户协议》和《隐私政策》各条款。' '您点击「同意」即表示您已阅读并同意上述协议。', String? userAgreementUrl, String? privacyPolicyUrl, String acceptText = '同意', String rejectText = '不同意', Future<void> onAccept()?})
const

Properties

acceptText String
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
onAccept Future<void> Function()?
点击「同意」后执行;完成后关闭弹窗并返回 true。 为 null 时默认 PrivacyPrefs.markAgreed
final
privacyPolicyUrl String?
final
rejectText String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
userAgreementUrl String?
final

Methods

copyWith({String? title, String? content, String? userAgreementUrl, String? privacyPolicyUrl, String? acceptText, String? rejectText, Future<void> onAccept()?}) PrivacyAgreementConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited