HttpUtilWithLoading class
带加载提示的 HttpUtil 包装类 用于链式调用,自动管理整个链路的加载提示
Constructors
- HttpUtilWithLoading(HttpUtil _httpUtil)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send<
T> ({required String method, required String path, dynamic data, Map< String, dynamic> ? queryParameters, Map<String, String> ? headers, int priority = 0, bool skipDeduplication = false, bool skipQueue = false, String? baseUrl, String? service}) → Future<Response< T> > - 发送请求(自动显示加载提示,用于链式调用) 整个链路共享一个加载提示,在链路结束时自动关闭
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited