DeduplicationMode enum
请求去重模式
Values
- deduplication → const DeduplicationMode
-
去重模式:相同请求共享同一个 Future
- debounce → const DeduplicationMode
-
防抖模式:延迟执行,如果在延迟期间有新请求,取消旧请求,执行新请求
- throttle → const DeduplicationMode
-
节流模式:在指定时间内只执行一次
- none → const DeduplicationMode
-
无去重:正常执行所有请求
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DeduplicationMode> - A constant List of the values in this enum, in order of their declaration.