PrivacyAgreementConfig class
隐私协议弹窗配置
Constructors
Properties
- acceptText → String
-
final
- content → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onAccept
→ Future<
void> Function()? -
点击「同意」后执行;完成后关闭弹窗并返回 true。
为 null 时默认 PrivacyPrefs.markAgreed。
final
- privacyPolicyUrl → String?
-
final
- rejectText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
- userAgreementUrl → String?
-
final
Methods
-
copyWith(
{String? title, String? content, String? userAgreementUrl, String? privacyPolicyUrl, String? acceptText, String? rejectText, Future< void> onAccept()?}) → PrivacyAgreementConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited